#!/usr/bin/perl
# $Id: 10_ftpusers.pl,v 1.5 2002/09/30 19:45:25 jthrowe Exp $
# 
# Name: 10_ftpusers.pl
# Date: 9/16/2002
#
# Description: This perl script verifies /etc/ftpusers after the
# install of proftpd.
#
# If /etc/ftpusers is modified prior to the install, then RPM will NOT
# overwrite it when the new proftpd is installed.  Instead it will
# leave /etc/ftpusers alone and install the new /etc/ftpusers as
# /etc/ftpusers.rpmnew.  
#
# If the original /etc/ftpusers was unmodified, then the new proftpd
# will install the correct /etc/ftpusers file and /etc/ftpusers.rpmnew
# won't be created.
#
# In the interest of security users should get the correct set of
# users in /etc/ftpusers.  Thus if /etc/ftpusers is a subset of
# /etc/ftpusers.rpmnew, then /etc/ftpusers.rpmnew is copied over
# /etc/ftpusers.  Otherwise, /etc/ftpusers is left alone.


# If file doesn't exist, then proftpd upgraded to the new /etc/ftpusers
open(FTPUSERSNEW, "/etc/ftpusers.rpmnew") || exit 0;

# Build array of new ftpusers
foreach $ftpuser (<FTPUSERSNEW>) {

        # comments and blank lines skipped
        next if $ftpuser =~ /^\s*#/;
        next unless $ftpuser =~ /\S/;
	chop($ftpuser);
	push(@FTPUSERSNEW, $ftpuser);
}

close FTPUSERSNEW;

# Open /etc/ftpusers and do a comparison
open (FTPUSERS, "/etc/ftpusers") || exit 0;

# See if there are any users in FTPUSERS that are NOT in FTPUSERSNEW.
# If so, FTPUSERS is NOT a subset of FTPUSERSNEW then exit leaving
# /etc/ftpusers alone.

foreach $ftpuser (<FTPUSERS>) {

        # comments and blank lines skipped
        next if $ftpuser =~ /^\s*#/;
        next unless $ftpuser =~ /\S/;
	chop($ftpuser);
        $found = 0;

	foreach $newuser (@FTPUSERSNEW) {
		if ($newuser eq $ftpuser) {
			$found = 1;
		}
	}

	if ($found == 0) {
	    close FTPUSERS;
	    exit (0);
	}
}

# close the file, since were done with it
close FTPUSERS;

# if we got here, ftpusers is subset of ftpusers.rpmnew
system ("cp /etc/ftpusers.rpmnew /etc/ftpusers");
system ("chmod 644 /etc/ftpusers");

exit 0;
